Peripherals

Struct Peripherals 

pub struct Peripherals {
Show 79 fields pub RMPU: Rmpu, pub TZF: Tzf, pub SRAM: Sram, pub BUS: Bus, pub DMAC0: Dmac0, pub DMAC1: Dmac0, pub DMAC2: Dmac0, pub DMAC3: Dmac0, pub DMAC4: Dmac0, pub DMAC5: Dmac0, pub DMAC6: Dmac0, pub DMAC7: Dmac0, pub DMA: Dma, pub DTC: Dtc, pub ICU: Icu, pub CACHE: Cache, pub CPSCU: Cpscu, pub DBG: Dbg, pub FCACHE: Fcache, pub SYSC: Sysc, pub PORT0: Port0, pub PORT2: Port2, pub PORTA: Porta, pub PORTB: Portb, pub PORTC: Portc, pub PORTD: Portd, pub PORTE: Porte, pub PFS_B: PfsB, pub IIRFA: Iirfa, pub TFU: Tfu, pub ELC_B: ElcB, pub IWDT: Iwdt, pub WDT: Wdt, pub CAC: Cac, pub MSTP: Mstp, pub KINT: Kint, pub POEG: Poeg, pub CANFD: Canfd, pub PSCU: Pscu, pub AGTW_B0: AgtwB0, pub AGTW_B1: AgtwB0, pub TSN: Tsn, pub ACMPHS0: Acmphs0, pub ACMPHS1: Acmphs0, pub ACMPHS2: Acmphs0, pub ACMPHS3: Acmphs0, pub CRC: Crc, pub DOC_B: DocB, pub SCI_B0: SciB0, pub SCI_B1: SciB0, pub SCI_B2: SciB0, pub SCI_B3: SciB0, pub SCI_B4: SciB0, pub SCI_B9: SciB0, pub SPI_B0: SpiB0, pub SPI_B1: SpiB0, pub IIC_B0: IicB0, pub IIC0WU_B: Iic0WuB, pub IIC_B1: IicB0, pub ECCMB: Eccmb, pub GPT320: Gpt320, pub GPT321: Gpt320, pub GPT322: Gpt320, pub GPT323: Gpt320, pub GPT324: Gpt324, pub GPT325: Gpt324, pub GPT326: Gpt324, pub GPT327: Gpt324, pub GPT328: Gpt324, pub GPT329: Gpt324, pub GPT_OPS: GptOps, pub GPT_GTCLK: GptGtclk, pub PDG: Pdg, pub ADC_B: AdcB, pub DAC120: Dac120, pub DAC121: Dac120, pub TSD: Tsd, pub FLAD: Flad, pub FACI: Faci,
}
Required for compatibility with RTIC and other frameworks

Fields

RMPU: RmpuTZF: TzfSRAM: SramBUS: BusDMAC0: Dmac0DMAC1: Dmac0DMAC2: Dmac0DMAC3: Dmac0DMAC4: Dmac0DMAC5: Dmac0DMAC6: Dmac0DMAC7: Dmac0DMA: DmaDTC: DtcICU: IcuCACHE: CacheCPSCU: CpscuDBG: DbgFCACHE: FcacheSYSC: SyscPORT0: Port0PORT2: Port2PORTA: PortaPORTB: PortbPORTC: PortcPORTD: PortdPORTE: PortePFS_B: PfsBIIRFA: IirfaTFU: TfuELC_B: ElcBIWDT: IwdtWDT: WdtCAC: CacMSTP: MstpKINT: KintPOEG: PoegCANFD: CanfdPSCU: PscuAGTW_B0: AgtwB0AGTW_B1: AgtwB0TSN: TsnACMPHS0: Acmphs0ACMPHS1: Acmphs0ACMPHS2: Acmphs0ACMPHS3: Acmphs0CRC: CrcDOC_B: DocBSCI_B0: SciB0SCI_B1: SciB0SCI_B2: SciB0SCI_B3: SciB0SCI_B4: SciB0SCI_B9: SciB0SPI_B0: SpiB0SPI_B1: SpiB0IIC_B0: IicB0IIC0WU_B: Iic0WuBIIC_B1: IicB0ECCMB: EccmbGPT320: Gpt320GPT321: Gpt320GPT322: Gpt320GPT323: Gpt320GPT324: Gpt324GPT325: Gpt324GPT326: Gpt324GPT327: Gpt324GPT328: Gpt324GPT329: Gpt324GPT_OPS: GptOpsGPT_GTCLK: GptGtclkPDG: PdgADC_B: AdcBDAC120: Dac120DAC121: Dac120TSD: TsdFLAD: FladFACI: Faci

Implementations

Source

impl Peripherals

pub fn take() -> Option<Self>

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks

pub fn steal() -> Self

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks